context("canvasXpress Web Charts - Contour")


test_that("cXcontour1", {
    check_ui_test(cXcontour1())
})

test_that("cXcontour2", {
    check_ui_test(cXcontour2())
})

test_that("cXcontour3", {
    check_ui_test(cXcontour3())
})

test_that("cXcontour4", {
    check_ui_test(cXcontour4())
})

test_that("cXcontour5", {
    check_ui_test(cXcontour5())
})

test_that("cXcontour6", {
    check_ui_test(cXcontour6())
})
